==> haskell-pcg-random-0.1.4.0-125.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-5QeFW3KRaDYDpv7pNd53N9
key:                  pcg-random-0.1.4.0-5QeFW3KRaDYDpv7pNd53N9
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  f314250323bcb68d1b1d2a88fb14bcfd
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-5QeFW3KRaDYDpv7pNd53N9
include-dirs:         /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcg-random-0.1.4.0-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-1gQfT2R8dgJK7BNcuAazQQ
key:                  pcg-random-0.1.4.0-1gQfT2R8dgJK7BNcuAazQQ
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  12a2feb464ad3ec72e4e665af6f3174c
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-1gQfT2R8dgJK7BNcuAazQQ
include-dirs:         /usr/lib/ghc-9.6.6/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
